# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 查询用户信息失败。
FAILEDOPERATION_ACCOUNTINFO = 'FailedOperation.AccountInfo'

# 查询应用信息失败。
FAILEDOPERATION_APPINFO = 'FailedOperation.AppInfo'

# 搜索接口异常。
FAILEDOPERATION_SEARCH = 'FailedOperation.Search'

# 数据上传异常。
FAILEDOPERATION_UPLOADDATAAPIFAIL = 'FailedOperation.UploadDataApiFail'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 数据文件无效。
INVALIDPARAMETER_DATACONTENT = 'InvalidParameter.DataContent'

# 请求的次数超过了频率限制。
LIMITEXCEEDED_SEARCH = 'LimitExceeded.Search'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
